You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ode.apache.org by mr...@apache.org on 2006/07/27 23:52:07 UTC

svn commit: r426260 [16/23] - in /incubator/ode/scratch/pxe-iapi: ./ axis2-examples/src/examples/DynPartner/ axis2-examples/src/examples/HelloWorld2/ axis2-examples/src/examples/MagicSession/ axis2-war/ axis2-war/src/main/webapp/WEB-INF/ axis2-war/src/...

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/AsyncProcess2.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/AsyncProcess2.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/AsyncProcess2.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/AsyncProcess2.wsdl Thu Jul 27 14:51:14 2006
@@ -58,17 +58,17 @@
 
    <service name="ProcessSVC">
         <port name="ProcessPORT" binding="proc:ProcessBIND">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/async2/invoke"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/async2/invoke"/>
         </port>
 	<port name="CallbackPORT" binding="proc:CallbackBIND">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/async2/callback"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/async2/callback"/>
         </port>
 
    </service>
 
   <service name="ResponderSVC">
         <port name="ResponderPORT" binding="resp:ResponderBIND">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/async2/callback"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/async2/callback"/>
         </port>
    </service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/build.xml Thu Jul 27 14:51:14 2006
@@ -4,8 +4,8 @@
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/async2/invoke"/>
-      <param name="pxe.sendsoap.filename" location="message.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/async2/invoke"/>
+      <param name="ode.sendsoap.filename" location="message.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess2/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor name="AsyncProcess2"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-  xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
+  xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
   wsdlUri="urn:/AsyncProcess2.wsdl"
-  xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+  xmlns="http://www.fivesight.com/ode/system-descriptor/"
   xmlns:proc="uri:com.bptest.process" 
   xmlns:resp="uri:com.bptest.responder">
   <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.bpel Thu Jul 27 14:51:14 2006
@@ -83,7 +83,7 @@
          <to variable="Request" part="payload" query="/typ:AsyncRequest/typ:Order"/>
         </copy>
         <copy>
-         <from expression="'http://localhost:8090/pxe/soap/AsyncProcess/ProcessSVC/CallbackPORT'"/>
+         <from expression="'http://localhost:8090/ode/soap/AsyncProcess/ProcessSVC/CallbackPORT'"/>
          <to variable="Request" part="payload" query="/typ:AsyncRequest/typ:CallbackEndpoint"/>
         </copy>
        </assign>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/AsyncProcess_NativeProtocol.wsdl Thu Jul 27 14:51:14 2006
@@ -58,14 +58,14 @@
 
    <service name="ProcessSVC">
         <port name="CallbackPORT" binding="proc:CallbackBIND">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/asyncNative/callback"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/asyncNative/callback"/>
         </port>
 
    </service>
 
   <service name="ResponderSVC">
         <port name="ResponderPORT" binding="resp:ResponderBIND">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/asyncNative/callback"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/asyncNative/callback"/>
         </port>
    </service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/build.xml Thu Jul 27 14:51:14 2006
@@ -7,20 +7,20 @@
     <javac srcdir="java"
       destdir="${build.dir}/classes"
       source="1.5"
-      classpathref="cpath.pxe" />
+      classpathref="cpath.ode" />
     <copy todir="${build.dir}/classes">
       <fileset file="java/payload.xml"/>
     </copy>
   </target>
   
   <target name="test" depends="compile" description="Invoke the native invoker." >
-    <echo message="pxe.url=${pxe.url}"/>
+    <echo message="ode.url=${ode.url}"/>
     <java classname="AsyncProcessNativeClient" fork="true">
       <classpath>
         <pathelement location="${build.dir}/classes" />
-        <path refid="cpath.pxe" />
+        <path refid="cpath.ode" />
       </classpath>
-      <jvmarg value="-Dpxe.url=${pxe.url}"/>
+      <jvmarg value="-Dode.url=${ode.url}"/>
     </java>
   </target>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/java/AsyncProcessNativeClient.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/java/AsyncProcessNativeClient.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor name="AsyncProcess_NativeProtocol"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-  xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
+  xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
   wsdlUri="urn:/AsyncProcess_NativeProtocol.wsdl"
-  xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+  xmlns="http://www.fivesight.com/ode/system-descriptor/"
   xmlns:proc="uri:com.bptest.process" 
   xmlns:resp="uri:com.bptest.responder">
   <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.bpel Thu Jul 27 14:51:14 2006
@@ -1,16 +1,16 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <process name="DynPartnerMain"
-         targetNamespace="http://pxe/bpel/unit-test"
+         targetNamespace="http://ode/bpel/unit-test"
          xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
          xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-         xmlns:tns="http://pxe/bpel/unit-test"
+         xmlns:tns="http://ode/bpel/unit-test"
          xmlns:xsd="http://www.w3.org/2001/XMLSchema"
          xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
-         xmlns:test="http://pxe/bpel/unit-test.wsdl"
-         xmlns:resp="http://pxe/bpel/responder.wsdl">
+         xmlns:test="http://ode/bpel/unit-test.wsdl"
+         xmlns:resp="http://ode/bpel/responder.wsdl">
 
-  <import location="urn:/Main.wsdl" namespace="http://pxe/bpel/unit-test.wsdl"
+  <import location="urn:/Main.wsdl" namespace="http://ode/bpel/unit-test.wsdl"
      importType="http://schemas.xmlsoap.org/wsdl/" />
 
   <partnerLinks>
@@ -69,7 +69,7 @@
     <assign>
       <copy>
         <from>
-          <literal>http://localhost:8080/pxe/soap/dynresponder</literal>
+          <literal>http://localhost:8080/ode/soap/dynresponder</literal>
         </from>
         <to partnerLink="responderPartnerLink"/>
       </copy>
@@ -77,7 +77,7 @@
         <from>
           <literal>
             <service-ref>
-              <soap:address location="http://localhost:8080/pxe/soap/dynresponder"/>
+              <soap:address location="http://localhost:8080/ode/soap/dynresponder"/>
             </service-ref>
           </literal>
         </from>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Main.wsdl Thu Jul 27 14:51:14 2006
@@ -1,17 +1,17 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
-    xmlns:resp="http://pxe/bpel/responder.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
+    xmlns:resp="http://ode/bpel/responder.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
     xmlns:plnk="http://schemas.xmlsoap.org/ws/2004/03/partner-link/">
 
-  <import namespace="http://pxe/bpel/responder.wsdl" location="Responder.wsdl"/>
+  <import namespace="http://ode/bpel/responder.wsdl" location="Responder.wsdl"/>
 
   <types>
     <xsd:element name="result" type="xsd:string"/>
@@ -33,17 +33,17 @@
     <wsdl:operation name="execute">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
       <wsdl:output>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:output>
     </wsdl:operation>
   </wsdl:binding>
 
   <wsdl:service name="DynMainService">
     <wsdl:port name="DynMainPort" binding="tns:DynMainBinding">
-      <soap:address location="http://localhost:8080/pxe/soap/dynmain"/>
+      <soap:address location="http://localhost:8080/ode/soap/dynmain"/>
     </wsdl:port>
   </wsdl:service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.bpel Thu Jul 27 14:51:14 2006
@@ -1,14 +1,14 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <process name="DynPartnerResponder"
-         targetNamespace="http://pxe/bpel/responder"
+         targetNamespace="http://ode/bpel/responder"
          xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
          xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-         xmlns:tns="http://pxe/bpel/responder"
+         xmlns:tns="http://ode/bpel/responder"
          xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-         xmlns:resp="http://pxe/bpel/responder.wsdl">
+         xmlns:resp="http://ode/bpel/responder.wsdl">
 
-  <import location="urn:/Responder.wsdl" namespace="http://pxe/bpel/responder.wsdl"
+  <import location="urn:/Responder.wsdl" namespace="http://ode/bpel/responder.wsdl"
      importType="http://schemas.xmlsoap.org/wsdl/" />
 
   <partnerLinks>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/Responder.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions
-        targetNamespace="http://pxe/bpel/responder.wsdl"
+        targetNamespace="http://ode/bpel/responder.wsdl"
         xmlns="http://schemas.xmlsoap.org/wsdl/"
-        xmlns:tns="http://pxe/bpel/responder.wsdl"
+        xmlns:tns="http://ode/bpel/responder.wsdl"
         xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
         xmlns:xsd="http://www.w3.org/2001/XMLSchema"
         xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -53,26 +53,26 @@
     <wsdl:operation name="getDynamicEndpoint">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/responder.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/responder.wsdl" use="literal"/>
       </wsdl:input>
       <wsdl:output>
-        <soap:body namespace="http://pxe/bpel/responder.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/responder.wsdl" use="literal"/>
       </wsdl:output>
     </wsdl:operation>
     <wsdl:operation name="acknowledge">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/responder.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/responder.wsdl" use="literal"/>
       </wsdl:input>
       <wsdl:output>
-        <soap:body namespace="http://pxe/bpel/responder.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/responder.wsdl" use="literal"/>
       </wsdl:output>
     </wsdl:operation>
   </wsdl:binding>
 
   <wsdl:service name="DynResponderService">
     <wsdl:port name="DynResponderPort" binding="tns:DynResponderBinding">
-      <soap:address location="http://localhost:8080/pxe/soap/dynresponder"/>
+      <soap:address location="http://localhost:8080/ode/soap/dynresponder"/>
     </wsdl:port>
   </wsdl:service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/build.xml Thu Jul 27 14:51:14 2006
@@ -6,7 +6,7 @@
     <echo>To build this example run:</echo>
     <echo>   ant main</echo>
     <echo>   ant responder</echo>
-    <echo>Then deploy the two generated SAR files using the pxe-deploy command and run:</echo>
+    <echo>Then deploy the two generated SAR files using the ode-deploy command and run:</echo>
     <echo>   ant test</echo>
     <echo>That's it!</echo>
   </target>
@@ -17,17 +17,17 @@
   <target name="_rr_responder" depends="init">
   	<delete dir="${build.dir}/responder.rr"/>
     <mkdir dir="${build.dir}/responder.rr"/>
-    <pxe-rr rrdir="${build.dir}/responder.rr">
+    <ode-rr rrdir="${build.dir}/responder.rr">
       <rrfileset dir="." includes="Responder.wsdl" desturi="urn:/" recursive="yes" />
-    </pxe-rr>
+    </ode-rr>
   </target>
 
   <target name="_rr_main" depends="init">
   	<delete dir="${build.dir}/main.rr"/>
     <mkdir dir="${build.dir}/main.rr"/>
-    <pxe-rr rrdir="${build.dir}/main.rr">
+    <ode-rr rrdir="${build.dir}/main.rr">
       <rrfileset dir="." includes="Main.wsdl" desturi="urn:/" recursive="yes" />
-    </pxe-rr>
+    </ode-rr>
   </target>
 
   <target name="_bpelc_responder" depends="init" >
@@ -43,23 +43,23 @@
   </target>
 
   <target name="_sar_responder" depends="init">
-    <pxe-sar destfile="${build.dir}/responder.sar"	systemrr="${build.dir}/responder.rr"	descriptor="pxe-responder-system.xml">
+    <ode-sar destfile="${build.dir}/responder.sar"	systemrr="${build.dir}/responder.rr"	descriptor="ode-responder-system.xml">
       <zipfileset file="${build.dir}/DynPartnerResponder.cbp" fullpath="DynPartnerResponder.cbp"/>
       <zipfileset file="${build.dir}/DynPartnerResponder.dd" fullpath="DynPartnerResponder.dd"/>
-    </pxe-sar>
+    </ode-sar>
   </target>
 
   <target name="_sar_main" depends="init">
-    <pxe-sar destfile="${build.dir}/main.sar"	systemrr="${build.dir}/main.rr"	descriptor="pxe-main-system.xml">
+    <ode-sar destfile="${build.dir}/main.sar"	systemrr="${build.dir}/main.rr"	descriptor="ode-main-system.xml">
       <zipfileset file="${build.dir}/DynPartnerMain.cbp" fullpath="DynPartnerMain.cbp"/>
       <zipfileset file="${build.dir}/DynPartnerMain.dd" fullpath="DynPartnerMain.dd"/>
-    </pxe-sar>
+    </ode-sar>
   </target>
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/dynmain"/>
-      <param name="pxe.sendsoap.filename" location="testRequest.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/dynmain"/>
+      <param name="ode.sendsoap.filename" location="testRequest.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-main-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-main-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-main-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-main-system.xml Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-                   xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-                   xmlns:hw="http://pxe/bpel/unit-test.wsdl"
-                   xmlns:resp="http://pxe/bpel/responder.wsdl"
-                   xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+                   xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+                   xmlns:hw="http://ode/bpel/unit-test.wsdl"
+                   xmlns:resp="http://ode/bpel/responder.wsdl"
+                   xmlns="http://www.fivesight.com/ode/system-descriptor/"
                    name="DynMain"
                    wsdlUri="urn:/Main.wsdl">
   <channels>
@@ -18,7 +18,7 @@
     </service>
     <service name="DynMainService.OutboundSoapService" provider="uri:protocoladapter.soap">
       <properties>
-        <property name="serviceWsdlNamespace" value="http://pxe/bpel/responder.wsdl"/>
+        <property name="serviceWsdlNamespace" value="http://ode/bpel/responder.wsdl"/>
         <property name="serviceWsdlName" value="DynResponderService"/>
       </properties>
       <exports>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-responder-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-responder-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-responder-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/pxe-responder-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
- xmlns:hw="http://pxe/bpel/responder.wsdl"
- xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+ xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+ xmlns:hw="http://ode/bpel/responder.wsdl"
+ xmlns="http://www.fivesight.com/ode/system-descriptor/"
  name="DynResponder"
  wsdlUri="urn:/Responder.wsdl">
     <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/readme.txt
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/readme.txt?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/readme.txt (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/readme.txt Thu Jul 27 14:51:14 2006
@@ -5,7 +5,7 @@
 ant responder
 ant main
 
-Deploy the two generated sar files using the 'pxe-deploy' command
+Deploy the two generated sar files using the 'ode-deploy' command
 and then run:
 
 ant test

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/testRequest.soap
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/testRequest.soap?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/testRequest.soap (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/DynPartner/testRequest.soap Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
   <!-- test soap message -->
   <SOAP-ENV:Body>
-    <!--<ns1:execute xmlns:ns1="http://pxe/bpel/unit-test.wsdl">-->
-        <ns2:dummy xmlns:ns2="http://pxe/bpel/responder.wsdl">fire!</ns2:dummy>
+    <!--<ns1:execute xmlns:ns1="http://ode/bpel/unit-test.wsdl">-->
+        <ns2:dummy xmlns:ns2="http://ode/bpel/responder.wsdl">fire!</ns2:dummy>
     <!--</ns1:execute>-->
   </SOAP-ENV:Body>
 </SOAP-ENV:Envelope>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.dd
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.dd?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.dd (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.dd Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<bpel:deployment-descriptor xmlns:bpel="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd">
+<bpel:deployment-descriptor xmlns:bpel="http://ode.fivesight.com/schemas/2006/02/14/bpeldd">
     <bpel:endpoint-refs>
         <bpel:endpoint-ref partnerLinkName="inboundPartnerLink" partnerLinkRole="myRole">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/geoIp" xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/geoIp" xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"/>
         </bpel:endpoint-ref>
         <bpel:endpoint-ref partnerLinkName="outboundPartnerLink" partnerLinkRole="partnerRole">
             <soap:address location="http://www.webservicex.net/geoipservice.asmx" xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"/>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/GeoIp.wsdl Thu Jul 27 14:51:14 2006
@@ -14,7 +14,7 @@
     <service name="GeoIpProxy">
         <documentation>A proxy to the GeoIP service</documentation>
         <port name="GeoIpSoap" binding="wsn:GeoIPServiceSoap">
-            <soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/geoIp"/>
+            <soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/geoIp"/>
         </port>
     </service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/build.xml Thu Jul 27 14:51:14 2006
@@ -4,8 +4,8 @@
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/geoIp"/>
-      <param name="pxe.sendsoap.filename" location="testRequest.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/geoIp"/>
+      <param name="ode.sendsoap.filename" location="testRequest.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/GeoIp/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -2,8 +2,8 @@
 <system-descriptor name="GeoIp" 
   wsdlUri="urn:/GeoIp.wsdl"
   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-  xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-  xmlns="http://www.fivesight.com/pxe/system-descriptor/" 
+  xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+  xmlns="http://www.fivesight.com/ode/system-descriptor/" 
   xmlns:wsn="http://www.webservicex.net">
   <channels>
     <channel name="inboundChannel" />

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.bpel Thu Jul 27 14:51:14 2006
@@ -1,10 +1,10 @@
 <process name="HelloWorld" 
-    targetNamespace="http://pxe/bpel/unit-test" 
+    targetNamespace="http://ode/bpel/unit-test" 
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
-    xmlns:tns="http://pxe/bpel/unit-test"
+    xmlns:tns="http://ode/bpel/unit-test"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:test="http://pxe/bpel/unit-test.wsdl">
+    xmlns:test="http://ode/bpel/unit-test.wsdl">
    <partnerLinks>
       <partnerLink name="helloPartnerLink" 
          partnerLinkType="test:HelloPartnerLinkType" 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.dd
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.dd?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.dd (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.dd Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <deployment-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xmlns="http://pxe.fivesight.com/schemas/2006/02/14/bpeldd">
+ xmlns="http://ode.fivesight.com/schemas/2006/02/14/bpeldd">
 
   <process-properties>
-    <property name="sample" namespace="http://www.fivesight.com/pxe/examples/HelloWorld/dd">someValue</property>
+    <property name="sample" namespace="http://www.fivesight.com/ode/examples/HelloWorld/dd">someValue</property>
   </process-properties>
 
 </deployment-descriptor>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/HelloWorld.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -27,19 +27,19 @@
             <soap:operation soapAction="" style="rpc"/>
             <wsdl:input>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl"
+                    namespace="http://ode/bpel/unit-test.wsdl"
                     use="literal"/>
             </wsdl:input>
             <wsdl:output>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl" 
+                    namespace="http://ode/bpel/unit-test.wsdl" 
                     use="literal"/>
             </wsdl:output>
         </wsdl:operation>
     </wsdl:binding>
     <wsdl:service name="HelloService">
 		<wsdl:port name="HelloPort" binding="tns:HelloSoapBinding">
-     		<soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/helloWorld"/>
+     		<soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/helloWorld"/>
 		</wsdl:port>
     </wsdl:service>
     

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/build.xml Thu Jul 27 14:51:14 2006
@@ -4,8 +4,8 @@
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/helloWorld"/>
-      <param name="pxe.sendsoap.filename" location="testRequest.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/helloWorld"/>
+      <param name="ode.sendsoap.filename" location="testRequest.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
- xmlns:hw="http://pxe/bpel/unit-test.wsdl"
- xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+ xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+ xmlns:hw="http://ode/bpel/unit-test.wsdl"
+ xmlns="http://www.fivesight.com/ode/system-descriptor/"
  name="HelloWorld"
  wsdlUri="urn:/HelloWorld.wsdl">
     <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/testRequest.soap
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/testRequest.soap?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/testRequest.soap (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld/testRequest.soap Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 <SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
   <!-- test soap message -->
   <SOAP-ENV:Body>
-    <ns1:hello xmlns:ns1="http://pxe/bpel/unit-test.wsdl">
+    <ns1:hello xmlns:ns1="http://ode/bpel/unit-test.wsdl">
         <TestPart xmlns="">Hello</TestPart>
     </ns1:hello>
   </SOAP-ENV:Body>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.bpel Thu Jul 27 14:51:14 2006
@@ -1,13 +1,13 @@
 <process name="HelloWorld2"
-    targetNamespace="http://pxe/bpel/unit-test" 
+    targetNamespace="http://ode/bpel/unit-test" 
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
     xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-    xmlns:tns="http://pxe/bpel/unit-test"
+    xmlns:tns="http://ode/bpel/unit-test"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:test="http://pxe/bpel/unit-test.wsdl">
+    xmlns:test="http://ode/bpel/unit-test.wsdl">
 
   <import location="urn:/HelloWorld2.wsdl"
-     namespace="http://pxe/bpel/unit-test.wsdl"
+     namespace="http://ode/bpel/unit-test.wsdl"
      importType="http://schemas.xmlsoap.org/wsdl/" />
 
    <partnerLinks>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/HelloWorld2.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -27,19 +27,19 @@
             <soap:operation soapAction="" style="rpc"/>
             <wsdl:input>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl"
+                    namespace="http://ode/bpel/unit-test.wsdl"
                     use="literal"/>
             </wsdl:input>
             <wsdl:output>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl" 
+                    namespace="http://ode/bpel/unit-test.wsdl" 
                     use="literal"/>
             </wsdl:output>
         </wsdl:operation>
     </wsdl:binding>
     <wsdl:service name="HelloService">
 		<wsdl:port name="HelloPort" binding="tns:HelloSoapBinding">
-     		<soap:address location="http://localhost:@PXE_HTTP_PORT@/pxe/soap/helloWorld"/>
+     		<soap:address location="http://localhost:@ODE_HTTP_PORT@/ode/soap/helloWorld"/>
 		</wsdl:port>
     </wsdl:service>
     

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/build.xml Thu Jul 27 14:51:14 2006
@@ -4,8 +4,8 @@
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/helloWorld"/>
-      <param name="pxe.sendsoap.filename" location="testRequest.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/helloWorld"/>
+      <param name="ode.sendsoap.filename" location="testRequest.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
- xmlns:hw="http://pxe/bpel/unit-test.wsdl"
- xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+ xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+ xmlns:hw="http://ode/bpel/unit-test.wsdl"
+ xmlns="http://www.fivesight.com/ode/system-descriptor/"
  name="HelloWorld2"
  wsdlUri="urn:/HelloWorld2.wsdl">
     <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/testRequest.soap
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/testRequest.soap?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/testRequest.soap (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld2/testRequest.soap Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 <SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
   <!-- test soap message -->
   <SOAP-ENV:Body>
-    <ns1:hello xmlns:ns1="http://pxe/bpel/unit-test.wsdl">
+    <ns1:hello xmlns:ns1="http://ode/bpel/unit-test.wsdl">
         <TestPart xmlns="">Hello</TestPart>
     </ns1:hello>
   </SOAP-ENV:Body>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.bpel Thu Jul 27 14:51:14 2006
@@ -4,7 +4,7 @@
     xmlns="http://schemas.xmlsoap.org/ws/2003/03/business-process/"
     xmlns:tns="http://jlo/bpel/unit-test"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:test="http://pxe/bpel/unit-test.wsdl">
+    xmlns:test="http://ode/bpel/unit-test.wsdl">
    <partnerLinks>
       <partnerLink name="helloPartnerLink"
          partnerLinkType="test:HelloPartnerLinkType"

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/HelloWorld_NativeProtocol.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/README.txt
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/README.txt?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/README.txt (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/README.txt Thu Jul 27 14:51:14 2006
@@ -1,6 +1,6 @@
 This example demonstrates the use of the "native" protocol adapter.  This allows
 sending/receiving WSDL message parts directly as xml strings, rather than through
 another protocol e.g. SOAP.  Connecting to the service provider for sending and
-receiving data is done via the PXE resource adapter (PxeConnectionFactory).  See
+receiving data is done via the ODE resource adapter (OdeConnectionFactory).  See
 the "HelloWorldNativeClient.java" for more detail.
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/build.xml Thu Jul 27 14:51:14 2006
@@ -7,17 +7,17 @@
     <javac srcdir="java"
       destdir="${build.dir}/classes"
       source="1.5"
-      classpathref="cpath.pxe" />
+      classpathref="cpath.ode" />
   </target>
 
   <target name="test" depends="compile" description="Invoke the native invoker." >
-    <echo message="pxe.url=${pxe.url}"/>
+    <echo message="ode.url=${ode.url}"/>
     <java fork="true" classname="HelloWorldNativeClient" >
       <classpath>
         <pathelement location="${build.dir}/classes" />
-        <path refid="cpath.pxe" />
+        <path refid="cpath.ode" />
       </classpath>
-      <jvmarg value="-Dpxe.url=${pxe.url}"/>
+      <jvmarg value="-Dode.url=${ode.url}"/>
     </java>
   </target>
 </project>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/java/HelloWorldNativeClient.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/java/HelloWorldNativeClient.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-  xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-  xmlns:hw="http://pxe/bpel/unit-test.wsdl"
-  xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+  xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+  xmlns:hw="http://ode/bpel/unit-test.wsdl"
+  xmlns="http://www.fivesight.com/ode/system-descriptor/"
   name="HelloWorld_NativeProtocol"
   wsdlUri="urn:/HelloWorld_NativeProtocol.wsdl">
   <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.bpel Thu Jul 27 14:51:14 2006
@@ -1,14 +1,14 @@
 <process name="HelloXslWorld" 
-    targetNamespace="http://pxe/bpel/unit-test" 
+    targetNamespace="http://ode/bpel/unit-test" 
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
     xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-    xmlns:tns="http://pxe/bpel/unit-test"
+    xmlns:tns="http://ode/bpel/unit-test"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:types="http://pxe/bpel/types"
-    xmlns:test="http://pxe/bpel/unit-test.wsdl">
+    xmlns:types="http://ode/bpel/types"
+    xmlns:test="http://ode/bpel/unit-test.wsdl">
 
    <import location="urn:/HelloXslWorld.wsdl"
-      namespace="http://pxe/bpel/unit-test.wsdl"
+      namespace="http://ode/bpel/unit-test.wsdl"
       importType="http://schemas.xmlsoap.org/wsdl/"/>
 
    <partnerLinks>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/HelloXslWorld.wsdl Thu Jul 27 14:51:14 2006
@@ -1,18 +1,18 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions 
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-    xmlns:types="http://pxe/bpel/types"
+    xmlns:types="http://ode/bpel/types"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
     xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
     xmlns:plnk="http://schemas.xmlsoap.org/ws/2004/03/partner-link/">
 
    <wsdl:types>
-      <xsd:schema targetNamespace="http://pxe/bpel/types">
+      <xsd:schema targetNamespace="http://ode/bpel/types">
 <!--         <xsd:element name="ContentCT"> -->
             <xsd:complexType name="ContentCT">
                <xsd:sequence>
@@ -40,19 +40,19 @@
             <soap:operation soapAction="" style="rpc"/>
             <wsdl:input>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl"
+                    namespace="http://ode/bpel/unit-test.wsdl"
                     use="literal"/>
             </wsdl:input>
             <wsdl:output>
                 <soap:body
-                    namespace="http://pxe/bpel/unit-test.wsdl" 
+                    namespace="http://ode/bpel/unit-test.wsdl" 
                     use="literal"/>
             </wsdl:output>
         </wsdl:operation>
     </wsdl:binding>
     <wsdl:service name="HelloXslService">
 		<wsdl:port name="HelloXslPort" binding="tns:HelloXslSoapBinding">
-     		<soap:address location="http://localhost:8080/pxe/soap/helloXslWorld"/>
+     		<soap:address location="http://localhost:8080/ode/soap/helloXslWorld"/>
 		</wsdl:port>
     </wsdl:service>
     

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/build.xml Thu Jul 27 14:51:14 2006
@@ -7,10 +7,10 @@
   <target name="_rr" depends="init">
     <delete dir="${rrfile}" />
     <mkdir dir="${rrfile}" />
-    <pxe-rr rrdir="${rrfile}">
+    <ode-rr rrdir="${rrfile}">
       <rrfileset dir="." includes="${wsdlfilename}" desturi="urn:/" recursive="yes" />
       <rrfileset dir="." includes="${xslfilename}" desturi="urn:/" recursive="yes" />
-    </pxe-rr>
+    </ode-rr>
   </target>
 
 </project>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
- xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
- xmlns:hw="http://pxe/bpel/unit-test.wsdl"
- xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+ xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+ xmlns:hw="http://ode/bpel/unit-test.wsdl"
+ xmlns="http://www.fivesight.com/ode/system-descriptor/"
  name="HelloXslWorld"
  wsdlUri="urn:/HelloXslWorld.wsdl">
     <channels>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/testRequest.soap
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/testRequest.soap?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/testRequest.soap (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloXslt/testRequest.soap Thu Jul 27 14:51:14 2006
@@ -1,7 +1,7 @@
 <SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
   <!-- test soap message -->
   <SOAP-ENV:Body>
-    <ns1:helloXsl xmlns:ns1="http://pxe/bpel/unit-test.wsdl">
+    <ns1:helloXsl xmlns:ns1="http://ode/bpel/unit-test.wsdl">
         <TestPart xmlns=""><content>HelloXsl</content></TestPart>
     </ns1:helloXsl>
   </SOAP-ENV:Body>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.bpel Thu Jul 27 14:51:14 2006
@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <process name="MagicSessionMain"
-         targetNamespace="http://pxe/bpel/unit-test"
+         targetNamespace="http://ode/bpel/unit-test"
          xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
          xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-         xmlns:tns="http://pxe/bpel/unit-test"
+         xmlns:tns="http://ode/bpel/unit-test"
          xmlns:xsd="http://www.w3.org/2001/XMLSchema"
          xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
-         xmlns:test="http://pxe/bpel/unit-test.wsdl">
+         xmlns:test="http://ode/bpel/unit-test.wsdl">
 
-  <import location="urn:/Main.wsdl" namespace="http://pxe/bpel/unit-test.wsdl"
+  <import location="urn:/Main.wsdl" namespace="http://ode/bpel/unit-test.wsdl"
      importType="http://schemas.xmlsoap.org/wsdl/" />
 
   <partnerLinks>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Main.wsdl Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <wsdl:definitions
-    targetNamespace="http://pxe/bpel/unit-test.wsdl"
+    targetNamespace="http://ode/bpel/unit-test.wsdl"
     xmlns="http://schemas.xmlsoap.org/wsdl/"
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl"
+    xmlns:tns="http://ode/bpel/unit-test.wsdl"
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
     xmlns:xsd="http://www.w3.org/2001/XMLSchema"
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -73,10 +73,10 @@
     <wsdl:operation name="execute">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
       <wsdl:output>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:output>
     </wsdl:operation>
   </wsdl:binding>
@@ -86,19 +86,19 @@
     <wsdl:operation name="callback">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
     <wsdl:operation name="doubleCallback">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
     <wsdl:operation name="tripleCallback">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
   </wsdl:binding>
@@ -108,35 +108,35 @@
     <wsdl:operation name="initiate">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
     <wsdl:operation name="doubleCall">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
     <wsdl:operation name="eprPassing">
       <soap:operation soapAction="" style="document"/>
       <wsdl:input>
-        <soap:body namespace="http://pxe/bpel/unit-test.wsdl" use="literal"/>
+        <soap:body namespace="http://ode/bpel/unit-test.wsdl" use="literal"/>
       </wsdl:input>
     </wsdl:operation>
   </wsdl:binding>
 
   <wsdl:service name="MSMainService">
     <wsdl:port name="MSMainInitiatePort" binding="tns:MSMainInitiateBinding">
-      <soap:address location="http://localhost:8080/pxe/soap/msmainInitiate"/>
+      <soap:address location="http://localhost:8080/ode/soap/msmainInitiate"/>
     </wsdl:port>
     <wsdl:port name="MSMainPort" binding="tns:MSMainBinding">
-      <soap:address location="http://localhost:8080/pxe/soap/msmain"/>
+      <soap:address location="http://localhost:8080/ode/soap/msmain"/>
     </wsdl:port>
   </wsdl:service>
 
   <wsdl:service name="MSResponderService">
     <wsdl:port name="MSResponderPort" binding="tns:MSResponderBinding">
-      <soap:address location="http://localhost:8080/pxe/soap/msresponder"/>
+      <soap:address location="http://localhost:8080/ode/soap/msresponder"/>
     </wsdl:port>
   </wsdl:service>
 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Responder.bpel
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Responder.bpel?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Responder.bpel (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/Responder.bpel Thu Jul 27 14:51:14 2006
@@ -1,14 +1,14 @@
 <?xml version="1.0" encoding="utf-8" ?>
 
 <process name="MagicSessionResponder"
-         targetNamespace="http://pxe/bpel/responder"
+         targetNamespace="http://ode/bpel/responder"
          xmlns:bpws="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
          xmlns="http://schemas.xmlsoap.org/ws/2004/03/business-process/"
-         xmlns:tns="http://pxe/bpel/responder"
+         xmlns:tns="http://ode/bpel/responder"
          xmlns:xsd="http://www.w3.org/2001/XMLSchema"
-         xmlns:resp="http://pxe/bpel/unit-test.wsdl">
+         xmlns:resp="http://ode/bpel/unit-test.wsdl">
 
-  <import location="urn:/Main.wsdl" namespace="http://pxe/bpel/unit-test.wsdl"
+  <import location="urn:/Main.wsdl" namespace="http://ode/bpel/unit-test.wsdl"
      importType="http://schemas.xmlsoap.org/wsdl/" />
 
   <partnerLinks>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/build.xml Thu Jul 27 14:51:14 2006
@@ -6,7 +6,7 @@
     <echo>To build this example run:</echo>
     <echo>   ant main</echo>
     <echo>   ant responder</echo>
-    <echo>Then deploy the two generated SAR files using the pxe-deploy command and run:</echo>
+    <echo>Then deploy the two generated SAR files using the ode-deploy command and run:</echo>
     <echo>   ant test</echo>
     <echo>That's it!</echo>
   </target>
@@ -17,17 +17,17 @@
   <target name="_rr_responder" depends="init">
   	<delete dir="${build.dir}/responder.rr"/>
     <mkdir dir="${build.dir}/responder.rr"/>
-    <pxe-rr rrdir="${build.dir}/responder.rr">
+    <ode-rr rrdir="${build.dir}/responder.rr">
       <rrfileset dir="." includes="Main.wsdl" desturi="urn:/" recursive="yes" />
-    </pxe-rr>
+    </ode-rr>
   </target>
 
   <target name="_rr_main" depends="init">
   	<delete dir="${build.dir}/main.rr"/>
     <mkdir dir="${build.dir}/main.rr"/>
-    <pxe-rr rrdir="${build.dir}/main.rr">
+    <ode-rr rrdir="${build.dir}/main.rr">
       <rrfileset dir="." includes="Main.wsdl" desturi="urn:/" recursive="yes" />
-    </pxe-rr>
+    </ode-rr>
   </target>
 
   <target name="_bpelc_responder" depends="init" >
@@ -43,23 +43,23 @@
   </target>
 
   <target name="_sar_responder" depends="init">
-    <pxe-sar destfile="${build.dir}/responder.sar"	systemrr="${build.dir}/responder.rr"	descriptor="pxe-responder-system.xml">
+    <ode-sar destfile="${build.dir}/responder.sar"	systemrr="${build.dir}/responder.rr"	descriptor="ode-responder-system.xml">
       <zipfileset file="${build.dir}/MagicSessionResponder.cbp" fullpath="MagicSessionResponder.cbp"/>
       <zipfileset file="${build.dir}/MagicSessionResponder.dd" fullpath="MagicSessionResponder.dd"/>
-    </pxe-sar>
+    </ode-sar>
   </target>
 
   <target name="_sar_main" depends="init">
-    <pxe-sar destfile="${build.dir}/main.sar"	systemrr="${build.dir}/main.rr"	descriptor="pxe-main-system.xml">
+    <ode-sar destfile="${build.dir}/main.sar"	systemrr="${build.dir}/main.rr"	descriptor="ode-main-system.xml">
       <zipfileset file="${build.dir}/MagicSessionMain.cbp" fullpath="MagicSessionMain.cbp"/>
       <zipfileset file="${build.dir}/MagicSessionMain.dd" fullpath="MagicSessionMain.dd"/>
-    </pxe-sar>
+    </ode-sar>
   </target>
 
   <target name="test" depends="init">
     <antcall target="_sendsoap">
-      <param name="pxe.sendsoap.url" value="http://localhost:${pxe.http.port}/pxe/soap/msmainInitiate"/>
-      <param name="pxe.sendsoap.filename" location="testRequest.soap"/>
+      <param name="ode.sendsoap.url" value="http://localhost:${ode.http.port}/ode/soap/msmainInitiate"/>
+      <param name="ode.sendsoap.filename" location="testRequest.soap"/>
     </antcall>
   </target>
   

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-main-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-main-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-main-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-main-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-                   xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-                   xmlns:main="http://pxe/bpel/unit-test.wsdl"
-                   xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+                   xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+                   xmlns:main="http://ode/bpel/unit-test.wsdl"
+                   xmlns="http://www.fivesight.com/ode/system-descriptor/"
                    name="MSMain"
                    wsdlUri="urn:/Main.wsdl">
   <channels>
@@ -19,7 +19,7 @@
     </service>
     <service name="msMainService.OutboundSoapService" provider="uri:protocoladapter.soap">
       <properties>
-        <property name="serviceWsdlNamespace" value="http://pxe/bpel/unit-test.wsdl"/>
+        <property name="serviceWsdlNamespace" value="http://ode/bpel/unit-test.wsdl"/>
         <property name="serviceWsdlName" value="MSResponderService"/>
       </properties>
       <exports>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-responder-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-responder-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-responder-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/pxe-responder-system.xml Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-                   xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-                   xmlns:main="http://pxe/bpel/unit-test.wsdl"
-                   xmlns="http://www.fivesight.com/pxe/system-descriptor/"
+                   xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+                   xmlns:main="http://ode/bpel/unit-test.wsdl"
+                   xmlns="http://www.fivesight.com/ode/system-descriptor/"
                    name="DynResponder"
                    wsdlUri="urn:/Main.wsdl">
   <channels>
@@ -17,7 +17,7 @@
     </service>
     <service name="msResponderService.OutboundSoapService" provider="uri:protocoladapter.soap">
       <properties>
-        <property name="serviceWsdlNamespace" value="http://pxe/bpel/unit-test.wsdl"/>
+        <property name="serviceWsdlNamespace" value="http://ode/bpel/unit-test.wsdl"/>
         <property name="serviceWsdlName" value="MSMainService"/>
       </properties>
       <exports>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/testRequest.soap
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/testRequest.soap?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/testRequest.soap (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/MagicSession/testRequest.soap Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
   <!-- test soap message -->
   <SOAP-ENV:Body>
-    <!--<ns1:execute xmlns:ns1="http://pxe/bpel/unit-test.wsdl">-->
-        <ns2:dummy xmlns:ns2="http://pxe/bpel/unit-test.wsdl">fire!</ns2:dummy>
+    <!--<ns1:execute xmlns:ns1="http://ode/bpel/unit-test.wsdl">-->
+        <ns2:dummy xmlns:ns2="http://ode/bpel/unit-test.wsdl">fire!</ns2:dummy>
     <!--</ns1:execute>-->
   </SOAP-ENV:Body>
 </SOAP-ENV:Envelope>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/build.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/build.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/build.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/build.xml Thu Jul 27 14:51:14 2006
@@ -7,17 +7,17 @@
     <javac srcdir="java"
       destdir="${build.dir}/classes"
       source="1.5"
-      classpathref="cpath.pxe" />
+      classpathref="cpath.ode" />
   </target>
 
   <target name="list" depends="compile" description="Get a list of processes." >
-    <echo message="pxe.url=${pxe.url}"/>
+    <echo message="ode.url=${ode.url}"/>
     <java classname="BpelManagementExample" fork="true">
       <classpath>
         <pathelement location="${build.dir}/classes" />
-        <path refid="cpath.pxe" />
+        <path refid="cpath.ode" />
       </classpath>
-      <jvmarg value="-Dpxe.url=${pxe.url}"/>
+      <jvmarg value="-Dode.url=${ode.url}"/>
     </java>
   </target>
 </project>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/java/BpelManagementExample.java
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/java/BpelManagementExample.java?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/RetailAggregator.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/RetailAggregator.wsdl Thu Jul 27 14:51:14 2006
@@ -1,8 +1,8 @@
 <?xml version="1.0" encoding="utf-8" ?>
 <wsdl:definitions 
-    targetNamespace="http://pxe/bpel/unit-test.wsdl" 
+    targetNamespace="http://ode/bpel/unit-test.wsdl" 
     xmlns="http://schemas.xmlsoap.org/wsdl/" 
-    xmlns:tns="http://pxe/bpel/unit-test.wsdl" 
+    xmlns:tns="http://ode/bpel/unit-test.wsdl" 
     xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/" 
     xmlns:xsd="http://www.w3.org/2001/XMLSchema" 
     xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/" 
@@ -12,14 +12,14 @@
     xmlns:cfgw='http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Configuration.wsdl' 
     xmlns:order='http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/RetailOrder.xsd'
     xmlns:cfg='http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Configuration.xsd'
-    xmlns:agreq="http://pxe/bpel/AggregatorRequest.xsd">
+    xmlns:agreq="http://ode/bpel/AggregatorRequest.xsd">
   <import 
       namespace="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl" 
       location="Retailer.wsdl"/>       
   <wsdl:types>
     <xsd:schema>
       <xsd:import
-          namespace="http://pxe/bpel/AggregatorRequest.xsd"
+          namespace="http://ode/bpel/AggregatorRequest.xsd"
           schemaLocation="AggregatorRequest.xsd"/>
     </xsd:schema>
   </wsdl:types>
@@ -64,7 +64,7 @@
         <soap:body
             parts="CustomerIdPart PartsOrder CustomerDetails ConfigurationHeader"
             use="literal"
-            namespace="http://pxe/bpel/unit-test.wsdl" />
+            namespace="http://ode/bpel/unit-test.wsdl" />
         <soap:header
             message="tns:SetupSessionMessage"
             part="ConfigurationHeader"
@@ -83,7 +83,7 @@
         <soap:body
             parts="CustomerIdPart LineItemsPart"
             use="literal"
-            namespace="http://pxe/bpel/unit-test.wsdl" />
+            namespace="http://ode/bpel/unit-test.wsdl" />
       </wsdl:input>
       <!--wsdl:output>
         <soap:body 
@@ -125,8 +125,8 @@
   </wsdl:binding>
   <wsdl:service name="AggregatorService">
     <wsdl:port name="AggregatorPort" binding="tns:AggregatorSoapBinding">
-      <!-- The soap:address is not used by PXE directly, but is useful for JAX-RPC generation -->
-      <soap:address location="http://localhost:8090/pxe/soap/Retailer/AggregatorService/AggregatorPort"/>
+      <!-- The soap:address is not used by ODE directly, but is useful for JAX-RPC generation -->
+      <soap:address location="http://localhost:8090/ode/soap/Retailer/AggregatorService/AggregatorPort"/>
     </wsdl:port>
   </wsdl:service>
   <plnk:partnerLinkType name="AggregatorPartnerLinkType">

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/Retailer.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/Retailer.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/Retailer.wsdl (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/Retailer.wsdl Thu Jul 27 14:51:14 2006
@@ -155,7 +155,7 @@
     </wsdl:binding>
     <wsdl:service name='RetailerServiceImplementation'>
         <wsdl:port name='RetailerServiceImplementationPort' binding='tns:RetailerSoapBinding'>
-            <soap:address location='http://localhost:@PXE_HTTP_PORT@/wsi-server/scm/retailer'/>
+            <soap:address location='http://localhost:@ODE_HTTP_PORT@/wsi-server/scm/retailer'/>
         </wsdl:port>
     </wsdl:service>
 </wsdl:definitions>

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/pxe-system.xml (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/pxe-system.xml Thu Jul 27 14:51:14 2006
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8" standalone="yes"?>
 <system-descriptor xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
-  xsi:schemaLocation="http://www.fivesight.com/pxe/system-descriptor/ http://www.fivesight.com/pxe/system-descriptor/"
-  xmlns:hw="http://pxe/bpel/unit-test.wsdl"
+  xsi:schemaLocation="http://www.fivesight.com/ode/system-descriptor/ http://www.fivesight.com/ode/system-descriptor/"
+  xmlns:hw="http://ode/bpel/unit-test.wsdl"
   xmlns:retail="http://www.ws-i.org/SampleApplications/SupplyChainManagement/2002-08/Retailer.wsdl"
-  xmlns="http://www.fivesight.com/pxe/system-descriptor/" name="Retailer" wsdlUri="file:src/bpel/Retailer/RetailAggregator.wsdl">
+  xmlns="http://www.fivesight.com/ode/system-descriptor/" name="Retailer" wsdlUri="file:src/bpel/Retailer/RetailAggregator.wsdl">
   <channels>
     <channel name="c1"/>
     <channel name="c2"/>
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/java/AsyncProcessNativeClient.java (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/java/AsyncProcessNativeClient.java Thu Jul 27 14:51:14 2006
@@ -1,30 +1,30 @@
 import java.io.ByteArrayOutputStream;
 import java.io.BufferedInputStream;
 
-import com.fs.pxe.xcontrib.sp.rpc.Request;
-import com.fs.pxe.xcontrib.sp.rpc.RpcInteraction;
-import com.fs.pxe.xcontrib.sp.rpc.Response;
-import com.fs.pxe.ra.PxeConnection;
-import com.fs.pxe.ra.PxeConnectionFactory;
-import com.fs.pxe.ra.PxeManagedConnectionFactory;
+import org.apache.ode.xcontrib.sp.rpc.Request;
+import org.apache.ode.xcontrib.sp.rpc.RpcInteraction;
+import org.apache.ode.xcontrib.sp.rpc.Response;
+import org.apache.ode.ra.OdeConnection;
+import org.apache.ode.ra.OdeConnectionFactory;
+import org.apache.ode.ra.OdeManagedConnectionFactory;
 
-import com.fs.utils.StreamUtils;
-import com.fs.utils.rmi.RMIConstants;
+import org.apache.ode.utils.StreamUtils;
+import org.apache.ode.utils.rmi.RMIConstants;
 
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 /**
  *  Demonstration of connecting to PXE using a PXE managed connection.
  *  There are two ways to 'acquire' a PxeConnectionFactory, either by deploying
  *  the PxeManagedConnectionFactory as a standard JCA resource and looking up
  *  the PxeConnectionFactory e.g.:
  *  InitialContext ctx = new InitialContext();
- *  PxeConnectionFactory cf = (PxeConnectionFactory)ctx.lookup(NAME_OF_BOUND_PXE_CF);
+ *  OdeConnectionFactory cf = (OdeConnectionFactory)ctx.lookup(NAME_OF_BOUND_ODE_CF);
  *  
  *  This examples uses the 2nd method, which is to explictly create the {@link PxeManagedConnectionFactory},
  *  configure it, and create the {@link PxeConnectionFactory}.  By default,
  *  the PxeManagedConnectionFactory will use an RMI protocol.
  */
 public class AsyncProcessNativeClient {
   
@@ -57,15 +57,15 @@
   
 	public static void main(String[] argv) throws Exception { 
     
-		PxeManagedConnectionFactory pmcf = new PxeManagedConnectionFactory();
+		OdeManagedConnectionFactory pmcf = new OdeManagedConnectionFactory();
     pmcf.setURL(RMIConstants.getConnectionURL());
-    PxeConnectionFactory cf = (PxeConnectionFactory)pmcf.createConnectionFactory();
-    PxeConnection conn = (PxeConnection)cf.getConnection();
+    OdeConnectionFactory cf = (OdeConnectionFactory)pmcf.createConnectionFactory();
+    OdeConnection conn = (OdeConnection)cf.getConnection();
     RpcInteraction interaction =
       (RpcInteraction)conn.createServiceProviderSession(
           "uri:protocoladapter.native.inbound", RpcInteraction.class);
     
     // the parameters of the RpcRequest match the settings in pxe-system.xml
     // for the native service provider
     Request request = new Request("AsyncProcess_NativeProtocol", // system name
                                               "AsyncProcess",              // service name
@@ -1,30 +1,30 @@
 
 /**
- *  Demonstration of connecting to PXE using a PXE managed connection.
- *  There are two ways to 'acquire' a PxeConnectionFactory, either by deploying
- *  the PxeManagedConnectionFactory as a standard JCA resource and looking up
- *  the PxeConnectionFactory e.g.:
+ *  Demonstration of connecting to ODE using a ODE managed connection.
+ *  There are two ways to 'acquire' a OdeConnectionFactory, either by deploying
+ *  the OdeManagedConnectionFactory as a standard JCA resource and looking up
+ *  the OdeConnectionFactory e.g.:
  *  InitialContext ctx = new InitialContext();
@@ -1,30 +1,30 @@
  *  
- *  This examples uses the 2nd method, which is to explictly create the {@link PxeManagedConnectionFactory},
- *  configure it, and create the {@link PxeConnectionFactory}.  By default,
- *  the PxeManagedConnectionFactory will use an RMI protocol.
+ *  This examples uses the 2nd method, which is to explictly create the {@link OdeManagedConnectionFactory},
+ *  configure it, and create the {@link OdeConnectionFactory}.  By default,
+ *  the OdeManagedConnectionFactory will use an RMI protocol.
  */
 public class AsyncProcessNativeClient {
@@ -57,15 +57,15 @@
           "uri:protocoladapter.native.inbound", RpcInteraction.class);
     
-    // the parameters of the RpcRequest match the settings in pxe-system.xml
+    // the parameters of the RpcRequest match the settings in ode-system.xml
     // for the native service provider
     Request request = new Request("AsyncProcess_NativeProtocol", // system name

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/AsyncProcess_NativeProtocol/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/java/HelloWorldNativeClient.java (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/java/HelloWorldNativeClient.java Thu Jul 27 14:51:14 2006
@@ -1,37 +1,37 @@
 
-import com.fs.pxe.xcontrib.sp.rpc.Request;
-import com.fs.pxe.xcontrib.sp.rpc.RpcInteraction;
-import com.fs.pxe.xcontrib.sp.rpc.Response;
-import com.fs.pxe.ra.PxeConnection;
-import com.fs.pxe.ra.PxeConnectionFactory;
-import com.fs.pxe.ra.PxeManagedConnectionFactory;
-import com.fs.utils.rmi.RMIConstants;
+import org.apache.ode.xcontrib.sp.rpc.Request;
+import org.apache.ode.xcontrib.sp.rpc.RpcInteraction;
+import org.apache.ode.xcontrib.sp.rpc.Response;
+import org.apache.ode.ra.OdeConnection;
+import org.apache.ode.ra.OdeConnectionFactory;
+import org.apache.ode.ra.OdeManagedConnectionFactory;
+import org.apache.ode.utils.rmi.RMIConstants;
 
 /**
  *  Demonstration of connecting to PXE using a PXE managed connection.
  *  There are two ways to 'acquire' a PxeConnectionFactory, either by deploying
  *  the PxeManagedConnectionFactory as a standard JCA resource and looking up
  *  the PxeConnectionFactory e.g.:
  *  InitialContext ctx = new InitialContext();
- *  PxeConnectionFactory cf = (PxeConnectionFactory)ctx.lookup(NAME_OF_BOUND_PXE_CF);
+ *  OdeConnectionFactory cf = (OdeConnectionFactory)ctx.lookup(NAME_OF_BOUND_ODE_CF);
  *  
  *  This examples uses the 2nd method, which is to explictly create the {@link PxeManagedConnectionFactory},
  *  configure it, and create the {@link PxeConnectionFactory}.  By default,
  *  the PxeManagedConnectionFactory will use an RMI protocol.
  */
 public class HelloWorldNativeClient {
   
 	public static void main(String[] argv) throws Exception { 
     
-		PxeManagedConnectionFactory pmcf = new PxeManagedConnectionFactory();
+		OdeManagedConnectionFactory pmcf = new OdeManagedConnectionFactory();
     pmcf.setURL(RMIConstants.getConnectionURL());
-    PxeConnectionFactory cf = (PxeConnectionFactory)pmcf.createConnectionFactory();
-    PxeConnection conn = (PxeConnection)cf.getConnection();
+    OdeConnectionFactory cf = (OdeConnectionFactory)pmcf.createConnectionFactory();
+    OdeConnection conn = (OdeConnection)cf.getConnection();
     RpcInteraction interaction =
       (RpcInteraction)conn.createServiceProviderSession(
           "uri:protocoladapter.native.inbound", RpcInteraction.class);
     
     // the parameters of the RpcRequest match the settings in pxe-system.xml
     // for the native service provider
     Request request = new Request("HelloWorld_NativeProtocol", // system name
                                               "HelloService",              // service name
@@ -1,37 +1,37 @@
 
 /**
- *  Demonstration of connecting to PXE using a PXE managed connection.
- *  There are two ways to 'acquire' a PxeConnectionFactory, either by deploying
- *  the PxeManagedConnectionFactory as a standard JCA resource and looking up
- *  the PxeConnectionFactory e.g.:
+ *  Demonstration of connecting to ODE using a ODE managed connection.
+ *  There are two ways to 'acquire' a OdeConnectionFactory, either by deploying
+ *  the OdeManagedConnectionFactory as a standard JCA resource and looking up
+ *  the OdeConnectionFactory e.g.:
  *  InitialContext ctx = new InitialContext();
@@ -1,37 +1,37 @@
  *  
- *  This examples uses the 2nd method, which is to explictly create the {@link PxeManagedConnectionFactory},
- *  configure it, and create the {@link PxeConnectionFactory}.  By default,
- *  the PxeManagedConnectionFactory will use an RMI protocol.
+ *  This examples uses the 2nd method, which is to explictly create the {@link OdeManagedConnectionFactory},
+ *  configure it, and create the {@link OdeConnectionFactory}.  By default,
+ *  the OdeManagedConnectionFactory will use an RMI protocol.
  */
 public class HelloWorldNativeClient {
@@ -1,37 +1,37 @@
           "uri:protocoladapter.native.inbound", RpcInteraction.class);
     
-    // the parameters of the RpcRequest match the settings in pxe-system.xml
+    // the parameters of the RpcRequest match the settings in ode-system.xml
     // for the native service provider
     Request request = new Request("HelloWorld_NativeProtocol", // system name

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/pxe-system.xml
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/HelloWorld_NativeProtocol/pxe-system.xml?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================
--- incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/java/BpelManagementExample.java (original)
+++ incubator/ode/scratch/pxe-iapi/examples/src/examples/ManagementAPI/java/BpelManagementExample.java Thu Jul 27 14:51:14 2006
@@ -4,12 +4,12 @@
  *
  */
 
-import com.fs.pxe.bpel.pmapi.*;
-import com.fs.pxe.bpel.provider.BpelManagementFacade;
-import com.fs.pxe.ra.PxeConnection;
-import com.fs.pxe.ra.PxeConnectionFactory;
-import com.fs.pxe.ra.PxeManagedConnectionFactory;
-import com.fs.utils.rmi.RMIConstants;
+import org.apache.ode.bpel.pmapi.*;
+import org.apache.ode.bpel.provider.BpelManagementFacade;
+import org.apache.ode.ra.OdeConnection;
+import org.apache.ode.ra.OdeConnectionFactory;
+import org.apache.ode.ra.OdeManagedConnectionFactory;
+import org.apache.ode.utils.rmi.RMIConstants;
 import com.sun.org.apache.xerces.internal.jaxp.DocumentBuilderFactoryImpl;
 
 import javax.xml.namespace.QName;
@@ -20,7 +20,7 @@
 
 /**
  * Demonstration of the Management API used to query and filter existing
  * processes and process instances. Simply acquires a connection to the PXE
  * engine and retrieves a ProcessManagement and InstanceManagement
  * implementation. 
  */
@@ -28,10 +28,10 @@
 
   public static void main(String[] argv) throws Exception {
 
-    PxeManagedConnectionFactory pmcf = new PxeManagedConnectionFactory();
+    OdeManagedConnectionFactory pmcf = new OdeManagedConnectionFactory();
     pmcf.setURL(RMIConstants.getConnectionURL());
-    PxeConnectionFactory cf = (PxeConnectionFactory)pmcf.createConnectionFactory();
-    PxeConnection conn = (PxeConnection)cf.getConnection();
+    OdeConnectionFactory cf = (OdeConnectionFactory)pmcf.createConnectionFactory();
+    OdeConnection conn = (OdeConnection)cf.getConnection();
     BpelManagementFacade bmf =
       (BpelManagementFacade)conn.createServiceProviderSession(
           "uri:bpelProvider", BpelManagementFacade.class);
@@ -49,14 +49,14 @@
 
     System.out.println("SETTING PROPERTY");
     pm.setProcessProperty(
-            "HelloWorld.helloWorld.BpelService", new QName("http://pxe", "testprop"), "118");
+            "HelloWorld.helloWorld.BpelService", new QName("http://ode", "testprop"), "118");
     ProcessInfoDocument pid = pm.setProcessProperty(
-            "HelloWorld.helloWorld.BpelService", new QName("http://pxe", "testnode"), doc);
+            "HelloWorld.helloWorld.BpelService", new QName("http://ode", "testnode"), doc);
     System.out.println(pid);
 
     System.out.println("PROCESSES:");
     ProcessInfoListDocument processInfoList = pm.listProcesses(
-        "name=Hello* namespace=http://pxe* status=activated "
+        "name=Hello* namespace=http://ode* status=activated "
         // Add to filter on deployment date.
         // + "deployed>=2005-11-29T15:11 deployed < 2005-11-29T15:13"
         ,"name +namespace -version");
@@ -64,7 +64,7 @@
 
     System.out.println("INSTANCES:");
     InstanceInfoListDocument instanceList = im.listInstances(
-        "name=Hello* namespace=http://pxe* status=completed|active "
+        "name=Hello* namespace=http://ode* status=completed|active "
         // Add to filter on started and last active date.
         // + "started>=2005-11-29T15:15:19 started<2005-11-29T15:15:20 "
         // + "last-active>=2005-11-29T15:15:19 last-active<2005-11-29T15:15:20"
@@ -20,7 +20,7 @@
 /**
  * Demonstration of the Management API used to query and filter existing
- * processes and process instances. Simply acquires a connection to the PXE
+ * processes and process instances. Simply acquires a connection to the ODE
  * engine and retrieves a ProcessManagement and InstanceManagement
  * implementation. 

Modified: incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/RetailAggregator.wsdl
URL: http://svn.apache.org/viewvc/incubator/ode/scratch/pxe-iapi/examples/src/examples/Retailer/RetailAggregator.wsdl?rev=426260&r1=426259&r2=426260&view=diff
==============================================================================